#!/bin/bash
#Author: Richard Heck (rgheck@brown.edu)
#License: GPL
#Version: 0.1
#Date: 2006-02-11
#Description: Script called by ps2pdf.desktop servicemenu
#Requirement: ps2pdf, KDE 3+

#USAGE: ps2pdf.sh [-d] [-c COMMAND] [-o OPTIONS] file1 [file2 ... fileN]
#By default, simply converts /path/FILE.ps to /path/FILE.pdf using ps2pdf
#Options:
#   -d: Use kdialog --getsavefilename to get filename of PDF
#   -D: Use kdialog --menu to display list of PDF formats
#   -c: Command to use for conversion (e.g., ps2pdf13)
#   -o: Options to pass to that command (e.g., -dPDFSETTINGS=/screen)
#Note: This will clobber the output file, if it already exists

PROG=`basename $0`;
INMIMETYPE="application/postscript";
OUTMIMETYPE="application/pdf";
OUTEXT=".pdf";
DEFAULTCOMMAND=ps2pdf

function errormsg {
  kdialog --error "Error in service menu script $PROG\n$*";
}

#Process command line arguments
while getopts ":dDc:o:" opt; do
  case $opt in
    d ) SAVEASDIALOG="TRUE";;     #Launches "save as" dialog
    D ) PDFDIALOG="TRUE";;
    c ) COMMAND="$OPTARG";;
    o)  OPTIONS="$OPTARG";;
    \?) echo "Warning ($PROG): Unrecognized option '$opt'.";
        exit 1;;
  esac
done

shift $(($OPTIND - 1));

#Display dialog box to get pdf format, if that was requested
if [ -n "$PDFDIALOG" ]; then
  COMMAND=`kdialog --menu "Choose PDF Format" ps2pdf "Acrobat 3.x+ compatible" ps2pdf13 "Acrobat 4.x+ compatible" ps2pdf14 "Acrobat 5.x+ compatible"`;
  if [ -z $COMMAND ]; then exit 0; fi; #Cancelled
fi

if [ -z "$COMMAND" ]; then COMMAND=$DEFAULTCOMMAND;
#Make sure we have a command we're prepared to run, ie, ps2pdf*
elif [ "$COMMAND" = "${COMMAND#ps2pdf}" ]; then
  echo "Warning ($PROG): Ignoring invalid command option '$COMMAND'.";
  COMMAND=$DEFAULTCOMMAND;
fi;

COMFILE=`which $COMMAND 2>/dev/null`;
if [ -z "$COMFILE" ]; then
  errormsg "No executable '$COMMAND' found in path.";
  exit 0;
fi

for INFILE in "$@"; do
  #Sanity checks
  if [ ! -r "$INFILE" ]; then
    errormsg "File '$INFILE' does not exist or is not readable.";
    continue;
  fi
  if  [ "`file -ib \"$INFILE\"`" != "$INMIMETYPE" ]; then
    errormsg "The mimetype of file '$INFILE' is not $INMIMETYPE.";
    continue;
  fi
  
  #Determine name of output file
  if [ -n "$SAVEASDIALOG" ]; then
    INDIR=`dirname "$INFILE"`;
    OUTFILE=`kdialog --caption "Save PDF As..." --icon pdf --getsavefilename "$INDIR" "$OUTMIMETYPE"`;
    if [ -z "$OUTFILE" ]; then
      #Dialog was cancelled
      echo "Save file dialog was cancelled. Skipping '$INFILE'.";
      continue;
    fi
  else
    #Strip old extension and add new one
    OUTFILE=${INFILE%.*}$OUTEXT;
  fi
  
  #Sanity check
  OUTDIR=`dirname "$OUTFILE"`;
  if [ ! -w "$OUTDIR" ]; then 
    errormsg "Directory '$OUTDIR' is not writeable by this process.";
    continue;
  fi
  
  #OK, we're actually ready to run the command and make a PDF
  $COMMAND $OPTIONS "$INFILE" "$OUTFILE";
done
